@@ -76,18 +76,20 @@ def pylons_deploy():
         # TODO: make backup
 
         if env.use_buildout:
+            if not exists('bootstrap.py'):
+                run('wget -q http://python-distribute.org/bootstrap.py')
+            put('buildout.cfg', os.path.join(env.cwd, 'buildout.cfg'))
             run('bin/python bootstrap.py')
             run('bin/buildout')
         
         # update DB
         run('bin/paster setup-app %(pylons_config)s' % env)
 
-        if exists('var/supervisor.pid'):
-            run('bin/supervisord')
-        else:
+        if exists('var/supervisord.pid'):
             # restart supervisor
             run('bin/supervisorctl restart %(project_name)s' % env)
-
+        else:
+            run('bin/supervisord')
 
 def _install_pylons_egg():
     local('%s setup.py sdist' % sys.executable)
